@@ -1,4 +1,4 @@
-`poLCA.se` <-
+poLCA.se <-
 function(y,x,probs,prior,rgivy) {
     J <- ncol(y)
     R <- ncol(prior)
